@@ -24,11 +24,11 @@ import textwrap
 
 from botocore.exceptions import ClientError
 
-from awscli.compat import shlex_quote, urlopen, ensure_text_type
+from awscli.compat import ensure_text_type, urlopen
 from awscli.customizations.commands import BasicCommand
+from awscli.customizations.exceptions import ParamValidationError
 from awscli.customizations.utils import create_client_from_parsed_globals
 
-
 LOG = logging.getLogger(__name__)
 
 IAM_USER_POLICY_NAME = "OpsWorks-Instance"
@@ -40,8 +40,9 @@ HOSTNAME_RE = re.compile(r"^(?!-)[a-z0-9-]{1,63}(?<!-)$", re.I)
 INSTANCE_ID_RE = re.compile(r"^i-[0-9a-f]+$")
 IP_ADDRESS_RE = re.compile(r"^\d+\.\d+\.\d+\.\d+$")
 
-IDENTITY_URL = \
+IDENTITY_URL = (
     "http://169.254.169.254/latest/dynamic/instance-identity/document"
+)
 
 REMOTE_SCRIPT = """
 set -e
@@ -77,49 +78,83 @@ class OpsWorksRegister(BasicCommand):
     """).strip()
 
     ARG_TABLE = [
-        {'name': 'stack-id', 'required': True,
-         'help_text': """A stack ID. The instance will be registered with the
-                         given stack."""},
-        {'name': 'infrastructure-class', 'required': True,
-         'choices': ['ec2', 'on-premises'],
-         'help_text': """Specifies whether to register an EC2 instance (`ec2`)
-                         or an on-premises instance (`on-premises`)."""},
-        {'name': 'override-hostname', 'dest': 'hostname',
-         'help_text': """The instance hostname. If not provided, the current
-                         hostname of the machine will be used."""},
-        {'name': 'override-private-ip', 'dest': 'private_ip',
-         'help_text': """An IP address. If you set this parameter, the given IP
+        {
+            'name': 'stack-id',
+            'required': True,
+            'help_text': """A stack ID. The instance will be registered with the
+                         given stack.""",
+        },
+        {
+            'name': 'infrastructure-class',
+            'required': True,
+            'choices': ['ec2', 'on-premises'],
+            'help_text': """Specifies whether to register an EC2 instance (`ec2`)
+                         or an on-premises instance (`on-premises`).""",
+        },
+        {
+            'name': 'override-hostname',
+            'dest': 'hostname',
+            'help_text': """The instance hostname. If not provided, the current
+                         hostname of the machine will be used.""",
+        },
+        {
+            'name': 'override-private-ip',
+            'dest': 'private_ip',
+            'help_text': """An IP address. If you set this parameter, the given IP
                          address will be used as the private IP address within
                          OpsWorks.  Otherwise the private IP address will be
                          determined automatically. Not to be used with EC2
-                         instances."""},
-        {'name': 'override-public-ip', 'dest': 'public_ip',
-         'help_text': """An IP address. If you set this parameter, the given IP
+                         instances.""",
+        },
+        {
+            'name': 'override-public-ip',
+            'dest': 'public_ip',
+            'help_text': """An IP address. If you set this parameter, the given IP
                          address will be used as the public IP address within
                          OpsWorks.  Otherwise the public IP address will be
                          determined automatically. Not to be used with EC2
-                         instances."""},
-        {'name': 'override-ssh', 'dest': 'ssh',
-         'help_text': """If you set this parameter, the given command will be
-                         used to connect to the machine."""},
-        {'name': 'ssh-username', 'dest': 'username',
-         'help_text': """If provided, this username will be used to connect to
-                         the host."""},
-        {'name': 'ssh-private-key', 'dest': 'private_key',
-         'help_text': """If provided, the given private key file will be used
-                         to connect to the machine."""},
-        {'name': 'local', 'action': 'store_true',
-         'help_text': """If given, instead of a remote machine, the local
+                         instances.""",
+        },
+        {
+            'name': 'override-ssh',
+            'dest': 'ssh',
+            'help_text': """If you set this parameter, the given command will be
+                         used to connect to the machine.""",
+        },
+        {
+            'name': 'ssh-username',
+            'dest': 'username',
+            'help_text': """If provided, this username will be used to connect to
+                         the host.""",
+        },
+        {
+            'name': 'ssh-private-key',
+            'dest': 'private_key',
+            'help_text': """If provided, the given private key file will be used
+                         to connect to the machine.""",
+        },
+        {
+            'name': 'local',
+            'action': 'store_true',
+            'help_text': """If given, instead of a remote machine, the local
                          machine will be imported. Cannot be used together
-                         with `target`."""},
-        {'name': 'use-instance-profile', 'action': 'store_true',
-         'help_text': """Use the instance profile instead of creating an IAM
-                         user."""},
-        {'name': 'target', 'positional_arg': True, 'nargs': '?',
-         'synopsis': '[<target>]',
-         'help_text': """Either the EC2 instance ID or the hostname of the
+                         with `target`.""",
+        },
+        {
+            'name': 'use-instance-profile',
+            'action': 'store_true',
+            'help_text': """Use the instance profile instead of creating an IAM
+                         user.""",
+        },
+        {
+            'name': 'target',
+            'positional_arg': True,
+            'nargs': '?',
+            'synopsis': '[<target>]',
+            'help_text': """Either the EC2 instance ID or the hostname of the
                          instance or machine to be registered with OpsWorks.
-                         Cannot be used together with `--local`."""},
+                         Cannot be used together with `--local`.""",
+        },
     ]
 
     def __init__(self, session):
@@ -135,7 +170,8 @@ class OpsWorksRegister(BasicCommand):
     def _create_clients(self, args, parsed_globals):
         self.iam = self._session.create_client('iam')
         self.opsworks = create_client_from_parsed_globals(
-            self._session, 'opsworks', parsed_globals)
+            self._session, 'opsworks', parsed_globals
+        )
 
     def _run_main(self, args, parsed_globals):
         self._create_clients(args, parsed_globals)
@@ -146,45 +182,55 @@ class OpsWorksRegister(BasicCommand):
         self.determine_details(args)
         self.create_iam_entities(args)
         self.setup_target_machine(args)
+        return 0
 
     def prevalidate_arguments(self, args):
         """
         Validates command line arguments before doing anything else.
         """
         if not args.target and not args.local:
-            raise ValueError("One of target or --local is required.")
+            raise ParamValidationError("One of target or --local is required.")
         elif args.target and args.local:
-            raise ValueError(
-                "Arguments target and --local are mutually exclusive.")
+            raise ParamValidationError(
+                "Arguments target and --local are mutually exclusive."
+            )
 
         if args.local and platform.system() != 'Linux':
-            raise ValueError(
-                "Non-Linux instances are not supported by AWS OpsWorks.")
+            raise ParamValidationError(
+                "Non-Linux instances are not supported by AWS OpsWorks."
+            )
 
         if args.ssh and (args.username or args.private_key):
-            raise ValueError(
+            raise ParamValidationError(
                 "Argument --override-ssh cannot be used together with "
-                "--ssh-username or --ssh-private-key.")
+                "--ssh-username or --ssh-private-key."
+            )
 
         if args.infrastructure_class == 'ec2':
             if args.private_ip:
-                raise ValueError(
-                    "--override-private-ip is not supported for EC2.")
+                raise ParamValidationError(
+                    "--override-private-ip is not supported for EC2."
+                )
             if args.public_ip:
-                raise ValueError(
-                    "--override-public-ip is not supported for EC2.")
+                raise ParamValidationError(
+                    "--override-public-ip is not supported for EC2."
+                )
 
-        if args.infrastructure_class == 'on-premises' and \
-                args.use_instance_profile:
-            raise ValueError(
-                "--use-instance-profile is only supported for EC2.")
+        if (
+            args.infrastructure_class == 'on-premises'
+            and args.use_instance_profile
+        ):
+            raise ParamValidationError(
+                "--use-instance-profile is only supported for EC2."
+            )
 
         if args.hostname:
             if not HOSTNAME_RE.match(args.hostname):
-                raise ValueError(
+                raise ParamValidationError(
                     "Invalid hostname: '%s'. Hostnames must consist of "
                     "letters, digits and dashes only and must not start or "
-                    "end with a dash." % args.hostname)
+                    "end with a dash." % args.hostname
+                )
 
     def retrieve_stack(self, args):
         """
@@ -195,18 +241,20 @@ class OpsWorksRegister(BasicCommand):
         """
 
         LOG.debug("Retrieving stack and provisioning parameters")
-        self._stack = self.opsworks.describe_stacks(
-            StackIds=[args.stack_id]
-        )['Stacks'][0]
-        self._prov_params = \
+        self._stack = self.opsworks.describe_stacks(StackIds=[args.stack_id])[
+            'Stacks'
+        ][0]
+        self._prov_params = (
             self.opsworks.describe_stack_provisioning_parameters(
                 StackId=self._stack['StackId']
             )
+        )
 
         if args.infrastructure_class == 'ec2' and not args.local:
             LOG.debug("Retrieving EC2 instance information")
             ec2 = self._session.create_client(
-                'ec2', region_name=self._stack['Region'])
+                'ec2', region_name=self._stack['Region']
+            )
 
             # `desc_args` are arguments for the describe_instances call,
             # whereas `conditions` is a list of lambdas for further filtering
@@ -232,9 +280,10 @@ class OpsWorksRegister(BasicCommand):
                 # Cannot search for either private or public IP at the same
                 # time, thus filter afterwards
                 conditions.append(
-                    lambda instance:
-                        instance.get('PrivateIpAddress') == args.target or
-                        instance.get('PublicIpAddress') == args.target)
+                    lambda instance: instance.get('PrivateIpAddress')
+                    == args.target
+                    or instance.get('PublicIpAddress') == args.target
+                )
                 # also use the given address to connect
                 self._use_address = args.target
             else:
@@ -253,12 +302,16 @@ class OpsWorksRegister(BasicCommand):
 
             if not instances:
                 raise ValueError(
-                    "Did not find any instance matching %s." % args.target)
+                    "Did not find any instance matching %s." % args.target
+                )
             elif len(instances) > 1:
                 raise ValueError(
-                    "Found multiple instances matching %s: %s." % (
+                    "Found multiple instances matching %s: %s."
+                    % (
                         args.target,
-                        ", ".join(i['InstanceId'] for i in instances)))
+                        ", ".join(i['InstanceId'] for i in instances),
+                    )
+                )
 
             self._ec2_instance = instances[0]
 
@@ -271,19 +324,24 @@ class OpsWorksRegister(BasicCommand):
             instances = self.opsworks.describe_instances(
                 StackId=self._stack['StackId']
             )['Instances']
-            if any(args.hostname.lower() == instance['Hostname']
-                   for instance in instances):
+            if any(
+                args.hostname.lower() == instance['Hostname']
+                for instance in instances
+            ):
                 raise ValueError(
                     "Invalid hostname: '%s'. Hostnames must be unique within "
-                    "a stack." % args.hostname)
+                    "a stack." % args.hostname
+                )
 
         if args.infrastructure_class == 'ec2' and args.local:
             # make sure the regions match
             region = json.loads(
-                ensure_text_type(urlopen(IDENTITY_URL).read()))['region']
+                ensure_text_type(urlopen(IDENTITY_URL).read())
+            )['region']
             if region != self._stack['Region']:
                 raise ValueError(
-                    "The stack's and the instance's region must match.")
+                    "The stack's and the instance's region must match."
+                )
 
     def determine_details(self, args):
         """
@@ -304,12 +362,14 @@ class OpsWorksRegister(BasicCommand):
                 elif 'PrivateIpAddress' in self._ec2_instance:
                     LOG.warning(
                         "Instance does not have a public IP address. Trying "
-                        "to use the private address to connect.")
+                        "to use the private address to connect."
+                    )
                     self._use_address = self._ec2_instance['PrivateIpAddress']
                 else:
                     # Should never happen
                     raise ValueError(
-                        "The instance does not seem to have an IP address.")
+                        "The instance does not seem to have an IP address."
+                    )
             elif args.infrastructure_class == 'on-premises':
                 self._use_address = args.target
 
@@ -342,7 +402,10 @@ class OpsWorksRegister(BasicCommand):
             self.iam.create_group(GroupName=group_name, Path=IAM_PATH)
             LOG.debug("Created IAM group %s", group_name)
         except ClientError as e:
-            if e.response.get('Error', {}).get('Code') == 'EntityAlreadyExists':
+            if (
+                e.response.get('Error', {}).get('Code')
+                == 'EntityAlreadyExists'
+            ):
                 LOG.debug("IAM group %s exists, continuing", group_name)
                 # group already exists, good
                 pass
@@ -353,17 +416,20 @@ class OpsWorksRegister(BasicCommand):
         LOG.debug("Creating an IAM user")
         base_username = "OpsWorks-%s-%s" % (
             shorten_name(clean_for_iam(self._stack['Name']), 25),
-            shorten_name(clean_for_iam(self._name_for_iam), 25)
+            shorten_name(clean_for_iam(self._name_for_iam), 25),
         )
         for try_ in range(20):
             username = base_username + ("+%s" % try_ if try_ else "")
             try:
                 self.iam.create_user(UserName=username, Path=IAM_PATH)
             except ClientError as e:
-                if e.response.get('Error', {}).get('Code') == 'EntityAlreadyExists':
+                if (
+                    e.response.get('Error', {}).get('Code')
+                    == 'EntityAlreadyExists'
+                ):
                     LOG.debug(
                         "IAM user %s already exists, trying another name",
-                        username
+                        username,
                     )
                     # user already exists, try the next one
                     pass
@@ -380,8 +446,7 @@ class OpsWorksRegister(BasicCommand):
 
         try:
             self.iam.attach_user_policy(
-                PolicyArn=IAM_POLICY_ARN,
-                UserName=username
+                PolicyArn=IAM_POLICY_ARN, UserName=username
             )
         except ClientError as e:
             if e.response.get('Error', {}).get('Code') == 'AccessDenied':
@@ -389,32 +454,29 @@ class OpsWorksRegister(BasicCommand):
                     "Unauthorized to attach policy %s to user %s. Trying "
                     "to put user policy",
                     IAM_POLICY_ARN,
-                    username
+                    username,
                 )
                 self.iam.put_user_policy(
                     PolicyName=IAM_USER_POLICY_NAME,
                     PolicyDocument=self._iam_policy_document(
-                        self._stack['Arn'], IAM_USER_POLICY_TIMEOUT),
-                    UserName=username
+                        self._stack['Arn'], IAM_USER_POLICY_TIMEOUT
+                    ),
+                    UserName=username,
                 )
                 LOG.debug(
-                    "Put policy %s to user %s",
-                    IAM_USER_POLICY_NAME,
-                    username
+                    "Put policy %s to user %s", IAM_USER_POLICY_NAME, username
                 )
             else:
                 raise
         else:
             LOG.debug(
-                "Attached policy %s to user %s",
-                IAM_POLICY_ARN,
-                username
+                "Attached policy %s to user %s", IAM_POLICY_ARN, username
             )
 
         LOG.debug("Creating an access key")
-        self.access_key = self.iam.create_access_key(
-            UserName=username
-        )['AccessKey']
+        self.access_key = self.iam.create_access_key(UserName=username)[
+            'AccessKey'
+        ]
 
     def setup_target_machine(self, args):
         """
@@ -423,12 +485,11 @@ class OpsWorksRegister(BasicCommand):
         """
 
         remote_script = REMOTE_SCRIPT % {
-            'agent_installer_url':
-                self._prov_params['AgentInstallerUrl'],
-            'preconfig':
-                self._to_ruby_yaml(self._pre_config_document(args)),
-            'assets_download_bucket':
-                self._prov_params['Parameters']['assets_download_bucket']
+            'agent_installer_url': self._prov_params['AgentInstallerUrl'],
+            'preconfig': self._to_ruby_yaml(self._pre_config_document(args)),
+            'assets_download_bucket': self._prov_params['Parameters'][
+                'assets_download_bucket'
+            ],
         }
 
         if args.local:
@@ -475,18 +536,18 @@ class OpsWorksRegister(BasicCommand):
                 call.append(self._use_address)
 
             remote_call = ["/bin/sh", "-c", remote_script]
-            call.append(" ".join(shlex_quote(word) for word in remote_call))
+            call.append(" ".join(shlex.quote(word) for word in remote_call))
             subprocess.check_call(call)
 
     def _pre_config_document(self, args):
         parameters = dict(
-            stack_id=self._stack['StackId'],
-            **self._prov_params["Parameters"]
+            stack_id=self._stack['StackId'], **self._prov_params["Parameters"]
         )
         if self.access_key:
             parameters['access_key_id'] = self.access_key['AccessKeyId']
-            parameters['secret_access_key'] = \
-                self.access_key['SecretAccessKey']
+            parameters['secret_access_key'] = self.access_key[
+                'SecretAccessKey'
+            ]
         if self._use_hostname:
             parameters['hostname'] = self._use_hostname
         if args.private_ip:
@@ -508,20 +569,20 @@ class OpsWorksRegister(BasicCommand):
             valid_until = datetime.datetime.utcnow() + timeout
             statement["Condition"] = {
                 "DateLessThan": {
-                    "aws:CurrentTime":
-                        valid_until.strftime("%Y-%m-%dT%H:%M:%SZ")
+                    "aws:CurrentTime": valid_until.strftime(
+                        "%Y-%m-%dT%H:%M:%SZ"
+                    )
                 }
             }
-        policy_document = {
-            "Statement": [statement],
-            "Version": "2012-10-17"
-        }
+        policy_document = {"Statement": [statement], "Version": "2012-10-17"}
         return json.dumps(policy_document)
 
     @staticmethod
     def _to_ruby_yaml(parameters):
-        return "\n".join(":%s: %s" % (k, json.dumps(v))
-                         for k, v in sorted(parameters.items()))
+        return "\n".join(
+            ":%s: %s" % (k, json.dumps(v))
+            for k, v in sorted(parameters.items())
+        )
 
 
 def clean_for_iam(name):
@@ -540,4 +601,4 @@ def shorten_name(name, max_length):
     if len(name) <= max_length:
         return name
     q, r = divmod(max_length - 3, 2)
-    return name[:q + r] + "..." + name[-q:]
+    return name[: q + r] + "..." + name[-q:]
