@@ -10,12 +10,10 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-"""
-"""
+""" """
 
 from awscli.customizations import utils
 
-
 ARGUMENT_RENAMES = {
     # Mapping of original arg to renamed arg.
     # The key is <service>.<operation>.argname
@@ -26,6 +24,8 @@ ARGUMENT_RENAMES = {
     'ec2.create-image.no-no-reboot': 'reboot',
     'ec2.*.no-egress': 'ingress',
     'ec2.*.no-disable-api-termination': 'enable-api-termination',
+    'opsworks.*.region': 'stack-region',
+    'elastictranscoder.*.output': 'job-output',
     'swf.register-activity-type.version': 'activity-version',
     'swf.register-workflow-type.version': 'workflow-version',
     'datapipeline.*.query': 'objects-query',
@@ -74,8 +74,7 @@ ARGUMENT_RENAMES = {
     'stepfunctions.send-task-success.output': 'task-output',
     'clouddirectory.publish-schema.version': 'schema-version',
     'mturk.list-qualification-types.query': 'types-query',
-    'workdocs.create-notification-subscription.endpoint':
-        'notification-endpoint',
+    'workdocs.create-notification-subscription.endpoint': 'notification-endpoint',
     'workdocs.describe-users.query': 'user-query',
     'lex-models.delete-bot.version': 'bot-version',
     'lex-models.delete-intent.version': 'intent-version',
@@ -94,7 +93,6 @@ ARGUMENT_RENAMES = {
     'eks.update-cluster-version.version': 'kubernetes-version',
     'eks.create-nodegroup.version': 'kubernetes-version',
     'eks.update-nodegroup-version.version': 'kubernetes-version',
-    'eks.update-cluster-components-version.version': 'kubernetes-version',
     'schemas.*.version': 'schema-version',
     'sagemaker.delete-image-version.version': 'version-number',
     'sagemaker.describe-image-version.version': 'version-number',
@@ -116,59 +114,41 @@ ARGUMENT_RENAMES = {
 # This is useful when you need to change the name of an argument but you
 # still need to support the old argument.
 HIDDEN_ALIASES = {
-    'cognito-identity.create-identity-pool.open-id-connect-provider-arns':
-        'open-id-connect-provider-ar-ns',
-    'storagegateway.describe-tapes.tape-arns': 'tape-ar-ns',
-    'storagegateway.describe-tape-archives.tape-arns': 'tape-ar-ns',
-    'storagegateway.describe-vtl-devices.vtl-device-arns': 'vtl-device-ar-ns',
-    'storagegateway.describe-cached-iscsi-volumes.volume-arns': 'volume-ar-ns',
-    'storagegateway.describe-stored-iscsi-volumes.volume-arns': 'volume-ar-ns',
-    'route53domains.view-billing.start-time': 'start',
-    # These come from the xform_name() changes that no longer separates words
-    # by numbers.
-    'deploy.create-deployment-group.ec2-tag-set': 'ec-2-tag-set',
-    'deploy.list-application-revisions.s3-bucket': 's-3-bucket',
-    'deploy.list-application-revisions.s3-key-prefix': 's-3-key-prefix',
-    'deploy.update-deployment-group.ec2-tag-set': 'ec-2-tag-set',
-    'iam.enable-mfa-device.authentication-code1': 'authentication-code-1',
-    'iam.enable-mfa-device.authentication-code2': 'authentication-code-2',
-    'iam.resync-mfa-device.authentication-code1': 'authentication-code-1',
-    'iam.resync-mfa-device.authentication-code2': 'authentication-code-2',
-    'importexport.get-shipping-label.street1': 'street-1',
-    'importexport.get-shipping-label.street2': 'street-2',
-    'importexport.get-shipping-label.street3': 'street-3',
-    'lambda.publish-version.code-sha256': 'code-sha-256',
-    'lightsail.import-key-pair.public-key-base64': 'public-key-base-64',
-    'mgn.*.replication-servers-security-groups-ids':
-        'replication-servers-security-groups-i-ds',
+    'mgn.*.replication-servers-security-groups-ids': 'replication-servers-security-groups-i-ds',
     'mgn.*.source-server-ids': 'source-server-i-ds',
-    'mgn.*.replication-configuration-template-ids':
-        'replication-configuration-template-i-ds',
-    'elasticache.create-replication-group.preferred-cache-cluster-azs':
-        'preferred-cache-cluster-a-zs'
+    'mgn.*.replication-configuration-template-ids': 'replication-configuration-template-i-ds',
+    'elasticache.create-replication-group.preferred-cache-cluster-azs': 'preferred-cache-cluster-a-zs',
 }
 
 
 def register_arg_renames(cli):
     for original, new_name in ARGUMENT_RENAMES.items():
         event_portion, original_arg_name = original.rsplit('.', 1)
-        cli.register('building-argument-table.%s' % event_portion,
-                     rename_arg(original_arg_name, new_name))
+        cli.register(
+            'building-argument-table.%s' % event_portion,
+            rename_arg(original_arg_name, new_name),
+        )
     for original, new_name in HIDDEN_ALIASES.items():
         event_portion, original_arg_name = original.rsplit('.', 1)
-        cli.register('building-argument-table.%s' % event_portion,
-                     hidden_alias(original_arg_name, new_name))
+        cli.register(
+            'building-argument-table.%s' % event_portion,
+            hidden_alias(original_arg_name, new_name),
+        )
 
 
 def rename_arg(original_arg_name, new_name):
     def _rename_arg(argument_table, **kwargs):
         if original_arg_name in argument_table:
             utils.rename_argument(argument_table, original_arg_name, new_name)
+
     return _rename_arg
 
 
 def hidden_alias(original_arg_name, alias_name):
     def _alias_arg(argument_table, **kwargs):
         if original_arg_name in argument_table:
-            utils.make_hidden_alias(argument_table, original_arg_name, alias_name)
+            utils.make_hidden_alias(
+                argument_table, original_arg_name, alias_name
+            )
+
     return _alias_arg
