@@ -31,6 +31,7 @@ from awscli.customizations.emr import (
 )
 from awscli.customizations.emr.command import Command
 from awscli.customizations.emr.constants import EC2_ROLE_NAME, EMR_ROLE_NAME
+from awscli.customizations.exceptions import ParamValidationError
 
 
 class CreateCluster(Command):
@@ -291,7 +292,7 @@ class CreateCluster(Command):
                         parsed_args.configurations
                     )
                 except ValueError:
-                    raise ValueError(
+                    raise ParamValidationError(
                         'aws: error: invalid json argument for '
                         'option --configurations'
                     )
@@ -695,7 +696,7 @@ class CreateCluster(Command):
             len(cluster_ba_list) + len(parsed_boostrap_actions)
             > constants.MAX_BOOTSTRAP_ACTION_NUMBER
         ):
-            raise ValueError(
+            raise ParamValidationError(
                 'aws: error: maximum number of '
                 'bootstrap actions for a cluster exceeded.'
             )
